@@ -1,7 +1,8 @@
-load_all()
-load("inst/extdata/arlington.Rdata")
-setwd("inst")
+# load_all()
+# load("inst/extdata/arlington.Rdata")
+# setwd("inst")
 
+data(aoristic)
 # testing aoristic.df
 data.ar <- aoristic.df(data=arlington, DateTimeFrom="DateTimeFrom", DateTimeTo="DateTimeTo")
 head(data.ar)
